function Map_Plot2


hfig = figure(1)
clf(hfig)
set(hfig, 'Units', 'inches', 'Position', [13 0.5 7 6]);
lw = 1.25; 



% PANEL A - K vs virulence, alpha > 0

% load K-alpha - high virulence (v = 0.07);
kv1=dlmread('Map_kv_1.txt'); % k-v map, assuming diff fhat, alpha > 0

% make plot
subplot(2,3,1)
xmin = 0.6; xmax=3; ymin = 0; ymax = 0.15; 
x1 = kv1(:,1); y1=kv1(:,2);
plot(kv1(:,1),kv1(:,2),'k-', 'LineWidth', lw); 
%fill([x1, fliplr(x1)], [y1 ymax*ones(size(y1))], 'r')
axis([xmin, xmax, ymin, ymax]);
ylabel({'Virulence mortality,';'{\it{v}} (dat^{-1})'},  'FontName', 'Arial', ...
    'FontSize', 10);
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [1, 3, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'a', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%0.2f'));
set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%0.1f'));




% PANEL B - K vs virulence, alpha (b) set to zero

% load K-v - b is 0.1 of default;
kv1b=dlmread('Map_kv_1b.txt'); % k-v map, assuming alpha (b) = 0


% make plot
subplot(2,3,2)
plot(kv1b(:,1),kv1b(:,2),'k-', 'LineWidth', lw); 

xmin = 0.6; xmax=3; ymin = 0; ymax = 0.15; 
axis([xmin, xmax, ymin, ymax]);
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [3, 3, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'b', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%0.2f'));
set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%0.1f'));
xlabel({'Carrying capacity,'; '{\itK} (mg/L)'},  ....
    'FontName', 'Arial',   'FontSize', 10);





% PANEL C- K vs virulence, alpha (b) > 0; four different sigmas

% load K-v -
kv3a=dlmread('Map_kv_1c.txt'); % k-v map, assuming alpha (b) = 0; sig1 = 25K
kv3b=dlmread('Map_kv_1d.txt'); % k-v map, assuming alpha (b) = 0; sig1 = 20K
kv3c=kv1; % the version with sigma = 15,000 - in panel A 
kv3d=dlmread('Map_kv_1e.txt'); % k-v map, assuming alpha (b) = 0; sig1 = 10K


% make plot
subplot(2,3,3)
plot(kv3a(:,1),kv3a(:,2),'k-', 'LineWidth', lw); hold on 
plot(kv3b(:,1),kv3b(:,2),'k:', 'LineWidth', lw); 
plot(kv3c(:,1),kv3c(:,2),'k-.', 'LineWidth', lw); 
plot(kv3d(:,1),kv3d(:,2),'k--', 'LineWidth', lw); hold off

xmin = 0.6; xmax=3; ymin = 0; ymax = 0.15; 
axis([xmin, xmax, ymin, ymax]);
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [5, 3, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'c', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%0.2f'));
set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%0.1f'));









% PANEL D - K vs alpha, high virulence

% load K-alpha - high virulence (v = 0.07);
ka1=dlmread('Map_ka_1.txt'); % k-alpha map, assuming diff fhat
ka2=dlmread('Map_ka_2.txt'); % k-alpha map, assuming same fhat

% make plot
subplot(2,3,4)
plot(ka1(:,1),ka1(:,2),'k-', 'LineWidth', lw); hold on
plot(ka2(:,1),ka2(:,2),'k--','LineWidth', lw);
xmin = 0.6; xmax=3; ymin = 0; ymax = 0.6; 
%x1 = ka1(:,1); y1=ka1(:,2);
%x2 = ka2(:,1); y2=ka2(:,2);
%fill([x1, fliplr(x1)], [y1 ymin*ones(size(y1))], 'r')
%fill([x2, fliplr(x2)], [y2 ymax*ones(size(y2))], 'r')

axis([xmin, xmax, ymin, ymax]);
ylabel({'Sensitivity of foraging,';'{\it\alpha} (mm^3 spore^-1 x 10^{-5})'},  'FontName', 'Arial', ...
    'FontSize', 10);
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [1, 1, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'd', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%0.1f'));
set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%0.1f'));




% PANEL E - K vs alpha, low virulence

% load K-alpha - low virulence (v = 0.03);
ka1b=dlmread('Map_ka_1b.txt'); % k-alpha map, assuming diff fhat
ka2b=dlmread('Map_ka_2b.txt'); % k-alpha map, assuming same fhat

% make plot
subplot(2,3,5)
plot(ka1b(:,1),ka1b(:,2),'k-', 'LineWidth', lw); hold on
plot(ka2b(:,1),ka2b(:,2),'k--','LineWidth', lw); hold off
xmin = 0.6; xmax=3; ymin = 0; ymax = 0.6; 
axis([xmin, xmax, ymin, ymax]);
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [3, 1, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'b', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%0.1f'));
set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%0.1f'));
xlabel({'Carrying capacity, {\itK} (mg/L)'},...
    'FontName', 'Arial',   'FontSize', 10);



set(gcf,'Color', 'w');
end







